import { select , geoNaturalEarth1} from 'd3'
import { feature } from 'topojson'
import { prepareData } from './prepareData';
import { drawMap } from './drawMap';

const queryLimit = 10000
const query = `PREFIX wgs84: <http://www.w3.org/2003/01/geo/wgs84_pos#>
PREFIX geo: <http://www.opengis.net/ont/geosparql#>
PREFIX skos: <http://www.w3.org/2004/02/skos/core#>
PREFIX gn: <http://www.geonames.org/ontology#>
PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>
PREFIX dc: <http://purl.org/dc/elements/1.1/>
SELECT * WHERE {
 ?svcn skos:exactMatch/wgs84:lat ?lat .
 ?svcn skos:exactMatch/wgs84:long ?long .
 ?svcn skos:exactMatch/gn:parentCountry ?land .
 ?land gn:name ?landLabel .
} LIMIT ${queryLimit}`
//Please use your own endpoint when using this 
const endpoint = "https://api.data.netwerkdigitaalerfgoed.nl/datasets/ivo/NMVW/services/NMVW-40/sparql"
const dataSource = 'https://gist.githubusercontent.com/Razpudding/f34e3dcabb5b950f468a68077cefda96/raw/a5a85adf3562e24e17a993c989f61ffcc9ecb2a1/surveyData.csv'
const svg = select('svg')

const mapSettings = {
  projection: geoNaturalEarth1(),
	circleDelay: 11,
	circleSize: 6
}

makeVisualization()

// Our main function which runs other function to make a visualization
async function makeVisualization(){
  //Draw the map using a module
	drawMap(svg, mapSettings.projection)
  const color = setupScales()
  console.log(color("kaas"))
  console.log(color(110))
  //Use the prepareData module to get and process our data
  let data = await prepareData(endpoint, query)
  console.log("Transformed data:", data)
  data.forEach(country => {
    console.log(country)
   plotLocations(svg, country.values, mapSettings.projection, color)
  })
plotAll(data)}

//Set up the scales we'll use
function setupScales(){
	return d3.scaleOrdinal(d3.schemeDark2)
}

//Todo: try this: https://stackoverflow.com/questions/7111584/using-nested-data-with-d3-js/7426206#7426206
function plotAll(data){
 	svg.selectAll('circle')
  	.data.map(d => d.values) 
}

//Plot each location on the map with a circle
function plotLocations(container, data, projection, color) {
  svg
    .selectAll('.'+ data[0].landLabel)
    .data(data)
    .enter()
    .append('circle')
      .attr('class', data[0].landLabel)
      .attr('cx', d => projection([d.long, d.lat])[0])
      .attr('cy', d => projection([d.long, d.lat])[1])
      .attr('r', '0px')
      .style('fill', d => color(d.landLabel))
      .transition()
  			//Delay calculation is still a work in progress
        .delay(d => svg.selectAll('circle').size() * mapSettings.circleDelay)//(d, i) => i * mapSettings.circleDelay)
        .duration(1500)
        .ease(d3.easeBounce)
        .attr('r', mapSettings.circleSize+'px')
}